@@ -16,9 +16,27 @@ var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__ge
 
 // src/lambdas/webhook-handler/index.ts
 var crypto = __toESM(require("crypto"));
+var AWS2 = __toESM(require("aws-sdk"));
+
+// src/lambdas/helpers.ts
 var AWS = __toESM(require("aws-sdk"));
-var sf = new AWS.StepFunctions();
 var sm = new AWS.SecretsManager();
+async function getSecretValue(arn) {
+  if (!arn) {
+    throw new Error("Missing secret ARN");
+  }
+  const secret = await sm.getSecretValue({ SecretId: arn }).promise();
+  if (!secret.SecretString) {
+    throw new Error(`No SecretString in ${arn}`);
+  }
+  return secret.SecretString;
+}
+async function getSecretJsonValue(arn) {
+  return JSON.parse(await getSecretValue(arn));
+}
+
+// src/lambdas/webhook-handler/index.ts
+var sf = new AWS2.StepFunctions();
 function verifyBody(event, secret) {
   const sig = Buffer.from(event.headers["x-hub-signature-256"] || "", "utf8");
   let body = event.body;
@@ -41,13 +59,7 @@ exports.handler = async function(event) {
   if (!process.env.WEBHOOK_SECRET_ARN || !process.env.STEP_FUNCTION_ARN) {
     throw new Error("Missing environment variables");
   }
-  const secret = await sm.getSecretValue({
-    SecretId: process.env.WEBHOOK_SECRET_ARN
-  }).promise();
-  if (!secret.SecretString) {
-    throw new Error(`No SecretString in ${process.env.WEBHOOK_SECRET_ARN}`);
-  }
-  const webhookSecret = JSON.parse(secret.SecretString).webhookSecret;
+  const webhookSecret = (await getSecretJsonValue(process.env.WEBHOOK_SECRET_ARN)).webhookSecret;
   let body;
   try {
     body = verifyBody(event, webhookSecret);
